poseidon-py
===========

Poseidon hash Python library with Hades permutation `implemented in C <https://github.com/CryptoExperts/poseidon>`_.

Currently, the parameters for poseidon hash are set to define the permutation used in Starknet.

They can be found in *poseidon_params.txt*.
